summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorKrishna Kumaar Natarajan <kknatara@qca.qualcomm.com>2016-03-18 14:54:35 -0700
committerAnjaneedevi Kapparapu <akappa@codeaurora.org>2016-03-22 18:30:35 +0530
commitf9d5812c7b89398d7ad43535fc01a49e1ddda7b2 (patch)
tree499c11eb025400296e711139784f11590422f4da
parent1aa3e5e0090f253e54e67dea0bfa378f60898e19 (diff)
qcacld-2.0: Fix misspelled variable name wps_registartion
Fix misspelled variable name wps_registartion by changing it to wps_registration. Change-Id: I5fc702200b9048b879ab1d0fada02e1da9a22638 CRs-Fixed: 992287
-rw-r--r--CORE/MAC/inc/sirApi.h2
-rw-r--r--CORE/MAC/src/pe/include/limSession.h2
-rw-r--r--CORE/MAC/src/pe/lim/limApi.c10
-rw-r--r--CORE/MAC/src/pe/lim/limProcessSmeReqMessages.c2
-rw-r--r--CORE/MAC/src/pe/lim/limSerDesUtils.c2
5 files changed, 9 insertions, 9 deletions
diff --git a/CORE/MAC/inc/sirApi.h b/CORE/MAC/inc/sirApi.h
index 461b5a5d5347..7a37b5e79eda 100644
--- a/CORE/MAC/inc/sirApi.h
+++ b/CORE/MAC/inc/sirApi.h
@@ -1053,7 +1053,7 @@ typedef struct sSirSmeJoinReq
#endif
tVOS_CON_MODE staPersona; //Persona
bool osen_association;
- bool wps_registartion;
+ bool wps_registration;
ePhyChanBondState cbMode; // Pass CB mode value in Join.
/*This contains the UAPSD Flag for all 4 AC
diff --git a/CORE/MAC/src/pe/include/limSession.h b/CORE/MAC/src/pe/include/limSession.h
index 29b3cfb14f08..19291837ef76 100644
--- a/CORE/MAC/src/pe/include/limSession.h
+++ b/CORE/MAC/src/pe/include/limSession.h
@@ -126,7 +126,7 @@ typedef struct sPESession // Added to Support BT-AMP
tSirNwType nwType;
tpSirSmeStartBssReq pLimStartBssReq; //handle to smestart bss req
bool osen_association;
- bool wps_registartion;
+ bool wps_registration;
tpSirSmeJoinReq pLimJoinReq; // handle to sme join req
tpSirSmeJoinReq pLimReAssocReq; //handle to sme reassoc req
tpLimMlmJoinReq pLimMlmJoinReq; //handle to MLM join Req
diff --git a/CORE/MAC/src/pe/lim/limProcessSmeReqMessages.c b/CORE/MAC/src/pe/lim/limProcessSmeReqMessages.c
index a0f15922316f..70bf4630475d 100644
--- a/CORE/MAC/src/pe/lim/limProcessSmeReqMessages.c
+++ b/CORE/MAC/src/pe/lim/limProcessSmeReqMessages.c
@@ -1954,7 +1954,7 @@ __limProcessSmeJoinReq(tpAniSirGlobal pMac, tANI_U32 *pMsgBuf)
psessionEntry->limWmeEnabled = pSmeJoinReq->isWMEenabled;
psessionEntry->limQosEnabled = pSmeJoinReq->isQosEnabled;
psessionEntry->osen_association = pSmeJoinReq->osen_association;
- psessionEntry->wps_registartion = pSmeJoinReq->wps_registartion;
+ psessionEntry->wps_registration = pSmeJoinReq->wps_registration;
/* Store vendor specfic IE for CISCO AP */
diff --git a/CORE/MAC/src/pe/lim/limSerDesUtils.c b/CORE/MAC/src/pe/lim/limSerDesUtils.c
index 83e042480701..56b43e248919 100644
--- a/CORE/MAC/src/pe/lim/limSerDesUtils.c
+++ b/CORE/MAC/src/pe/lim/limSerDesUtils.c
@@ -935,7 +935,7 @@ limJoinReqSerDes(tpAniSirGlobal pMac, tpSirSmeJoinReq pJoinReq, tANI_U8 *pBuf)
limLog(pMac, LOGE, FL("remaining len %d is too short"), len);
return eSIR_FAILURE;
}
- pJoinReq->wps_registartion = *pBuf++;
+ pJoinReq->wps_registration = *pBuf++;
len--;
if (limCheckRemainingLength(pMac, len) == eSIR_FAILURE)
{
diff --git a/CORE/MAC/src/pe/lim/limApi.c b/CORE/MAC/src/pe/lim/limApi.c
index 31bbd1edb451..57e75f945a14 100644
--- a/CORE/MAC/src/pe/lim/limApi.c
+++ b/CORE/MAC/src/pe/lim/limApi.c
@@ -1805,7 +1805,7 @@ lim_enc_type_matched(tpAniSirGlobal mac_ctx,
FL("session:: Privacy :%d EncyptionType: %d OSEN %d WPS %d"),
SIR_MAC_GET_PRIVACY(session->limCurrentBssCaps),
session->encryptType, session->osen_association,
- session->wps_registartion);
+ session->wps_registration);
/* This is handled by sending probe req due to IOT issues so return TRUE */
if ((bcn->capabilityInfo.privacy) !=
@@ -1843,10 +1843,10 @@ lim_enc_type_matched(tpAniSirGlobal mac_ctx,
* in beacon. Therefore no need to
* check for security type in case
* OSEN session.
- * For WPS registration session no need to detect
- * detect security mismatch as it wont match and
+ * For WPS registration session no need to
+ * detect security mismatch as it won't match and
* driver may end up sending probe request without
* WPS IE during WPS registartion process.
*/
/*TODO: AP capability mismatch
* is not checked here because
@@ -1854,7 +1854,7 @@ lim_enc_type_matched(tpAniSirGlobal mac_ctx,
* is avilable for HS2.0
*/
if (session->osen_association ||
- session->wps_registartion)
+ session->wps_registration)
return eSIR_TRUE;
return false;
@@ -1843,10 +1843,10 @@ lim_enc_type_matched(tpAniSirGlobal mac_ctx,
* driver may end up sending probe request without
- * WPS IE during WPS registartion process.
+ * WPS IE during WPS registration process.
*/
/*TODO: AP capability mismatch